/*
 * CONTRAT DE LICENCE DE LOGICIEL LIBRE CeCILL-B
 * https://cecill.info/licences/Licence_CeCILL-B_V1-fr.html
 */
package fr.unistra.sil.erp.back.controller.api;

import static fr.unistra.sil.erp.back.WebMvcConfig.MAPPING_ITEMS;

import fr.unistra.sil.erp.back.controller.IRetrieveInfoController;
import fr.unistra.sil.erp.back.model.Item;

import java.util.List;

import fr.unistra.sil.erp.back.repository.IItemsRepository;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * REST controller for the item list.
 *
 * @author BEAUVAIS ANTOINE
 */
@RestController
public class ApiRetrieveItemsController implements IRetrieveInfoController {

    private final IItemsRepository repository;

    public ApiRetrieveItemsController(IItemsRepository repository) {
        this.repository = repository;
    }

    /**
     * Returns all products as a JSON response.
     *
     * @param cat an optional category.
     * @return a JSON response.
     * @throws ApiServerErrorException if the request could not be served.
     * @throws ApiBadRequestException  if the category parameter is invalid.
     */
    @GetMapping(MAPPING_ITEMS)
    public ResponseEntity<Object> retrieveInfo(
            @RequestParam(value = "category", defaultValue = "") String cat
    ) throws ApiServerErrorException, ApiBadRequestException {
        List<Item> res;
        if (cat.equals(""))
            res = repository.getAllItems();
        else {
            int category;
            try {
                category = Integer.parseInt(cat);
            } catch (NumberFormatException ex) {
                throw new ApiBadRequestException("Category must be a integer.");
            }

            res = repository.getItemsFromCategory(category);
        }

        if (res == null)
            throw new ApiServerErrorException("Failed to query info.");
        else if (res.isEmpty())
            return ResponseEntity.noContent().build();

        return new ResponseEntity<>(res, HttpStatus.OK);
    }
}
