/*
 * CONTRAT DE LICENCE DE LOGICIEL LIBRE CeCILL-B
 * https://cecill.info/licences/Licence_CeCILL-B_V1-fr.html
 */
package fr.unistra.sil.erp.back.model;

import java.math.BigDecimal;
import java.util.Date;

/**
 * Entry in the Registry.
 * 
 * The registry contains all credit and debit operations relative to
 * the operating organization.
 * 
 * @author BEAUVAIS ANTOINE
 */
public class RegistryEntry {
    
    /**
     * The entry's ID.
     */
    private final Integer id;
    
    /**
     * The transaction's type.
     */
    private final int transactionType;
    
    /**
     * The date and time for this transaction.
     */
    private final Date dt;
    
    /**
     * The ID of the associated account.
     */
    private final int accountId;
    
    /**
     * The amount of money, if it's a debit.
     */
    private final BigDecimal debit;
    
    /**
     * The amount of money, if it's a credit.
     */
    private final BigDecimal credit;
    
    /**
     * Arbitrary remarks. Optional.
     */
    private final String remarks;
    
    /**
     * Class constructor.
     * @param id the entry's ID.
     * @param transactionType the transaction type.
     * @param dt the date and time.
     * @param accountId the associated account's ID.
     * @param debit money for the debit.
     * @param credit money for the credit.
     * @param remarks arbitrary remarks.
     */
    public RegistryEntry(Integer id, int transactionType, Date dt,
            int accountId, BigDecimal debit, BigDecimal credit,
            String remarks)
    {
        this.id = id;
        this.transactionType = transactionType;
        this.dt = dt;
        this.accountId = accountId;
        this.debit = debit;
        this.credit = credit;
        this.remarks = remarks;
    }
    
    /**
     * Returns the entry's ID.
     * @return the entry's ID.
     */
    public Integer getId()
    {
        return this.id;
    }
    
    /**
     * Returns the transaction's type.
     * @return the transaction's type.
     */
    public int getTransactionType()
    {
        return this.transactionType;
    }
    
    /**
     * Returns the transaction's date and time.
     * @return the date and time.
     */
    public Date getDatetime()
    {
        return this.dt;
    }
    
    /**
     * Returns the associated account's ID.
     * @return the associated account's ID.
     */
    public int getAccountId()
    {
        return this.accountId;
    }
    
    /**
     * Returns the debit amount.
     * @return the amount.
     */
    public BigDecimal getDebit()
    {
        return this.debit;
    }
    
    /**
     * Returns the credit amount.
     * @return the amount.
     */
    public BigDecimal getCredit()
    {
        return this.credit;
    }
    
    /**
     * Returns the arbitrary remarks.
     * @return the remarks.
     */
    public String getRemarks()
    {
        return this.remarks;
    }
    
}
